--- old/usr/src/Makefile.smatch	Mon Jul 15 07:12:19 2019
+++ new/usr/src/Makefile.smatch	Mon Jul 15 07:12:19 2019
@@ -8,7 +8,7 @@
 # source.  A copy of the CDDL is also available via the Internet at
 # http://www.illumos.org/license/CDDL.
 #
-# Copyright (c) 2019, Joyent, Inc.
+# Copyright 2019 Joyent, Inc.
 #
 
 #
@@ -27,6 +27,8 @@
 # we have lots of legacy "void foo();" in headers
 SMATCH_ARGS += -Wno-old-style-definition
 SMATCH_ARGS += -Wno-strict-prototypes
+SMATCH_ARGS += --fatal-checks
+SMATCH_ARGS += --timeout=120
 
 CERRWARN += $(SMATCH_ARGS:%=-_smatch=%)
 
--- old/usr/src/tools/env/illumos.sh	Mon Jul 15 07:12:20 2019
+++ new/usr/src/tools/env/illumos.sh	Mon Jul 15 07:12:20 2019
@@ -84,8 +84,8 @@
 export SHADOW_CCS=gcc4,/opt/gcc/4.4.4/bin/gcc,gnu
 export SHADOW_CCCS=gcc4,/opt/gcc/4.4.4/bin/g++,gnu
 
-# uncomment to enable smatch
-#export ENABLE_SMATCH=1
+# comment to disable smatch
+export ENABLE_SMATCH=1
 
 # Comment this out to disable support for SMB printing, i.e. if you
 # don't want to bother providing the CUPS headers this needs.
--- old/usr/src/tools/smatch/Makefile	Mon Jul 15 07:12:20 2019
+++ new/usr/src/tools/smatch/Makefile	Mon Jul 15 07:12:20 2019
@@ -13,7 +13,7 @@
 
 #
 # The src/ sub-directory is un-modified copy of
-# https://github.com/illumos/smatch/tree/0.5.1-il-1
+# https://github.com/illumos/smatch/tree/0.5.1-il-3
 #
 # This Makefile installs just enough for us to be able to run smatch
 # locally.
@@ -20,7 +20,7 @@
 #
 
 PROG = smatch
-SPARSE_VERSION = 0.5.1-il-1
+SPARSE_VERSION = 0.5.1-il-3
 
 include ../Makefile.tools
 
--- old/usr/src/tools/smatch/src/smatch.c	Mon Jul 15 07:12:20 2019
+++ new/usr/src/tools/smatch/src/smatch.c	Mon Jul 15 07:12:20 2019
@@ -13,6 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see http://www.gnu.org/copyleft/gpl.txt
+ *
+ * Copyright 2019 Joyent, Inc.
  */
 
 #include <stdio.h>
@@ -43,6 +45,7 @@
 char *option_datadir_str;
 int option_fatal_checks;
 int option_succeed;
+int option_timeout = 60;
 
 FILE *sm_outfd;
 FILE *sql_outfd;
@@ -173,7 +176,7 @@
 }
 
 #define OPTION(_x) do {					\
-	if (match_option((*argvp)[1], #_x)) { 		\
+	if (match_option((*argvp)[i], #_x)) { 		\
 		option_##_x = 1;			\
 	}                                               \
 } while (0)
@@ -218,6 +221,12 @@
 			option_disable = 1;
 		}
 
+		if (!strncmp((*argvp)[i], "--timeout=", 10)) {
+			if (sscanf((*argvp)[i] + 10, "%d",
+			    &option_timeout) != 1)
+				sm_fatal("invalid option %s", (*argvp)[i]);
+		}
+
 		OPTION(fatal_checks);
 		OPTION(spammy);
 		OPTION(info);
--- old/usr/src/tools/smatch/src/smatch.h	Mon Jul 15 07:12:21 2019
+++ new/usr/src/tools/smatch/src/smatch.h	Mon Jul 15 07:12:21 2019
@@ -13,6 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see http://www.gnu.org/copyleft/gpl.txt
+ *
+ * Copyright 2019 Joyent, Inc.
  */
 
 #ifndef   	SMATCH_H_
@@ -200,6 +202,7 @@
 extern int local_debug;
 extern int option_info;
 extern int option_spammy;
+extern int option_timeout;
 extern char *trace_variable;
 extern struct stree *global_states;
 int is_skipped_function(void);
--- old/usr/src/tools/smatch/src/smatch_implied.c	Mon Jul 15 07:12:21 2019
+++ new/usr/src/tools/smatch/src/smatch_implied.c	Mon Jul 15 07:12:21 2019
@@ -13,6 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see http://www.gnu.org/copyleft/gpl.txt
+ *
+ * Copyright 2019 Joyent, Inc.
  */
 
 /*
@@ -397,7 +399,7 @@
 	if (out_of_memory())
 		return 1;
 
-	if (time_parsing_function() < 60)
+	if (time_parsing_function() < option_timeout)
 		return 0;
 
 	if (!__inline_fn && printed != cur_func_sym) {
@@ -593,7 +595,7 @@
 
 	gettimeofday(&time_after, NULL);
 	sec = time_after.tv_sec - time_before.tv_sec;
-	if (sec > 20) {
+	if (sec > option_timeout) {
 		sm->nr_children = 4000;
 		sm_perror("Function too hairy.  Ignoring implications after %d seconds.", sec);
 	}
